/*! \file   include/tm.h
    \brief  Header file for task management.
    \author Markus L. Noga <noga@inrialpes.fr>
    
    Defines types and flags used in task management.
*/
    
/*
 *  The contents of this file are subject to the Mozilla Public License
 *  Version 1.0 (the "License"); you may not use this file except in
 *  compliance with the License. You may obtain a copy of the License at
 *  http://www.mozilla.org/MPL/
 *
 *  Software distributed under the License is distributed on an "AS IS"
 *  basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 *  License for the specific language governing rights and limitations
 *  under the License.
 *
 *  The Original Code is legOS code, released March 19, 1999.
 *
 *  The Initial Developer of the Original Code is Markus L. Noga.
 *  Portions created by Markus L. Noga are Copyright (C) 1999
 *  Markus L. Noga. All Rights Reserved.
 *
 *  Contributor(s): Markus L. Noga <noga@inrialpes.fr>
 */

#ifndef __tm_h__
#define __tm_h__

#include "mem.h"

///////////////////////////////////////////////////////////////////////////////
//
// Definitions
//
///////////////////////////////////////////////////////////////////////////////

typedef unsigned char pstate_t;			//!< process state type
typedef unsigned char priority_t;		//!< process priority type
typedef unsigned long wakeup_t;			//!< wakeup data area type

//
// process states
//

#define P_DEAD		0			//!< dead and gone, stack freed
#define	P_ZOMBIE	1			//!< terminated, cleanup pending
#define P_WAITING	2			//!< waiting for an event
#define P_SLEEPING	3			//!< sleeping. wants to run.
#define P_RUNNING	4			//!< running


#define DEFAULT_STACK_SIZE	1024		//!< 1k stack has to suffice.


//! process data structure
/*
*/
struct _process_data {
	size_t	*sp_save;			//!< saved stack pointer
	
	pstate_t pstate;			//!< process state
	priority_t priority;                    //!< process priority
		
	struct _process_data *next;		//!< next process in queue
	struct _process_data *prev;		//!< previous process in queue

	struct _process_data *parent;		//!< parent process

	size_t *stack_base;			//!< lower stack boundary
	
	wakeup_t (*wakeup)(wakeup_t);		//!< event wakeup function
	wakeup_t wakeup_data;			//!< user data for wakeup fn
	
};

//! process data type
/*! a shorthand
*/
typedef struct _process_data process_data;

//! process id type
/*! In effect, the kernel simply typecasts *process_data to pid_t.
*/
typedef size_t  pid_t;

#endif
